@@ -28,10 +28,12 @@ MainWindow::MainWindow(QWidget *parent) :
 dir.setNameFilters(QStringList()<<"*.bin"<<"*.iso"<<"*.img");
 
          QFileInfoList list = dir.entryInfoList();
+         int o=0;
          for (int i = 0; i < list.size(); ++i) {
              QFileInfo fileInfo = list.at(i);
+             if (fileInfo.fileName()=="scph1001.bin")continue;
              ui->listWidget->addItem(new QListWidgetItem(fileInfo.fileName()));
-             roms.insert(i,fileInfo.absoluteFilePath());
+             roms.insert(o++,fileInfo.absoluteFilePath());
          }
          connect(ui->pushButton,SIGNAL(clicked()),this,SLOT(runGame()));
 
@@ -80,6 +82,13 @@ dir.setNameFilters(QStringList()<<"*.bin"<<"*.iso"<<"*.img");
 
         this->menuBar()->addAction(tr("Configure keys"),keyopt,SLOT(exec()));
         this->setWindowTitle("PSX4M-Gui");
+       if (!QFile("/home/opt/psx4m/keys").exists()){
+           system ("mkdir -p /home/opt/psx4m");
+           QMessageBox msg;
+           msg.setText(tr("You should set keys to use psx4m"));
+           msg.exec();
+           keyopt->exec();
+       }
 }
 void MainWindow::select_dir(){
     QString dir;
@@ -95,10 +104,12 @@ void MainWindow::select_dir(){
    dir.setNameFilters(QStringList()<<"*.bin"<<"*.iso"<<"*.img");
 
             QFileInfoList list = dir.entryInfoList();
+            int o=0;
             for (int i = 0; i < list.size(); ++i) {
                 QFileInfo fileInfo = list.at(i);
+                if (fileInfo.fileName()=="scph1001.bin")continue;
                 ui->listWidget->addItem(new QListWidgetItem(fileInfo.fileName()));
-                roms.insert(i,fileInfo.absoluteFilePath());
+                roms.insert(o++,fileInfo.absoluteFilePath());
             }
    }
 }
